﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2013 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using System.Collections.Generic;
using Irony.Interpreter;
using Irony.Parsing;

namespace HeuristicLab.BenchmarkGenerator {
  class ExpressionEvaluator {
    public ExpressionGrammar Grammar { get; private set; }
    public Parser Parser { get; private set; }
    public LanguageData Language { get; private set; }
    public LanguageRuntime Runtime { get; private set; }
    public ScriptApp App { get; private set; }
    public IDictionary<string, object> Globals { get { return App.Globals; } }

    public ExpressionEvaluator() : this(new ExpressionGrammar()) { }

    public ExpressionEvaluator(ExpressionGrammar grammar) {
      Grammar = grammar;
      Language = new LanguageData(Grammar);
      Parser = new Parser(Language);
      Runtime = Grammar.CreateRuntime(Language);
      App = new ScriptApp(Runtime);
    }

    public object Evaluate(ParseTree parsedScript) {
      var result = App.Evaluate(parsedScript);
      return result;
    }

    public object Evaluate() {
      return App.Evaluate();
    }

    public void ClearOutput() {
      App.ClearOutputBuffer();
    }

    public string GetOutput() {
      return App.GetOutput();
    }
  }
}
